@@ -25,17 +25,19 @@ class AuthenticatedMSTRRESTSession(MSTRRESTSession):
         username: str = None,
         password: str = None,
         identity_token: str = None,
+        application_type: int = 8,
     ):
         super(AuthenticatedMSTRRESTSession, self).__init__(base_url)
         self._username = username
         self._password = password
         self._identity_token = identity_token
+        self._application_type = application_type
 
     def __enter__(self):
         if self._identity_token is not None:
             self.delegate(self._identity_token)
         else:
-            self.login(self._username, self._password)
+            self.login(self._username, self._password, self._application_type)
         return self
 
     def __exit__(self, t, v, tb):
