@@ -1,3 +1,18 @@
+# -*- coding: utf-8 -*-
+# Copyright 2020 Paul Bailey
+#
+#    Licensed under the Apache License, Version 2.0 (the "License");
+#    you may not use this file except in compliance with the License.
+#    You may obtain a copy of the License at
+#
+#        https://www.apache.org/licenses/LICENSE-2.0
+#
+#    Unless required by applicable law or agreed to in writing, software
+#    distributed under the License is distributed on an "AS IS" BASIS,
+#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#    See the License for the specific language governing permissions and
+#    limitations under the License.
+
 from requests_toolbelt.sessions import BaseUrlSession
 
 from mstr.requests.rest import exceptions
@@ -17,7 +32,15 @@ class MSTRBaseSession(BaseUrlSession):
         except KeyError:
             pass
 
-    def request(self, method, url, include_auth=True, project_id=None, *args, **kwargs):
+    def request(
+        self,
+        method: str,
+        url: str,
+        include_auth=True,
+        project_id: str = None,
+        *args,
+        **kwargs
+    ):
 
         headers = kwargs.get("headers", {})
 
@@ -52,6 +75,6 @@ class MSTRBaseSession(BaseUrlSession):
                 )
         if response.ok:
             for key, value in response.headers.items():
-                if key.startswith("X-MSTR"):
+                if key.upper().startswith("X-MSTR"):
                     self.headers.update({key: value})
         return response
